@@ -15,7 +15,6 @@ from dask import config
 import coiled
 from .chess_util import ChessUtil
 
-
 class ChessDaskCluster:
     "Class for using dask tasks to parallelize calculation of heatmap"
     @staticmethod
@@ -80,7 +79,7 @@ class ChessDaskCluster:
             print("Game timed out: " + str(game_no))
         return game_data
 
-    def __init__(self):
+    def __init__(self,cluster_type=None):
         config_file = os.path.join(os.getcwd(), "config", "config.yaml")
         if not os.path.isfile(config_file):
             raise FileNotFoundError(
@@ -108,23 +107,40 @@ class ChessDaskCluster:
         if not "debug" in self.config_values:
             self.config_values["debug"] = False
 
-        if self.config_values["use_local_cluster"]:
-            cluster = LocalCluster(n_workers=self.config_values["n_workers"],
-                                    threads_per_worker=1)
-        else:
-            coiled.create_software_environment(name=self.config_values["software_environment_name"],
-                                                pip="requirements.txt")
-            cluster = coiled.Cluster(name=self.config_values["cluster_name"],
-                                    n_workers=self.config_values["n_workers"],
-                                    worker_cpu=self.config_values["worker_cpu"],
-                                    worker_memory=str(self.config_values["worker_memory"])
-                                                        +"GiB",
-                                    scheduler_memory=str(self.config_values["scheduler_memory"])
-                                                        +"GiB",
-                                    scheduler_cpu=self.config_values["scheduler_cpu"],
-                                    software=self.config_values["software_environment_name"])
 
-        self.client = Client(cluster)
+        if cluster_type == None:
+            if self.config_values["use_local_cluster"]:
+                ChessDaskCluster.create_local_env(self)
+
+            else:
+                ChessDaskCluster.create_coiled_env(self)
+        
+
+        else:
+            if cluster_type == "local_cluster":
+                ChessDaskCluster.create_local_env(self)
+            elif cluster_type == "coiled_cluster":
+                ChessDaskCluster.create_coiled_env(self)
+
+
+        self.client = Client(self.cluster)
+
+    def create_local_env(self):
+        self.cluster = LocalCluster(n_workers=self.config_values["n_workers"],threads_per_worker=1)
+    
+    def create_coiled_env(self):
+        coiled.create_software_environment(name=self.config_values["software_environment_name"],
+                                                pip="requirements.txt")
+        self.cluster = coiled.Cluster(name=self.config_values["cluster_name"],
+                                n_workers=self.config_values["n_workers"],
+                                worker_cpu=self.config_values["worker_cpu"],
+                                worker_memory=str(self.config_values["worker_memory"])
+                                                    +"GiB",
+                                scheduler_memory=str(self.config_values["scheduler_memory"])
+                                                    +"GiB",
+                                scheduler_cpu=self.config_values["scheduler_cpu"],
+                                software=self.config_values["software_environment_name"])
+
 
     def analyse_games_in_cluster(self, game_list, handler):
         "Find control heatmap for all the games passed, in parallel in a dask cluster"
@@ -151,4 +167,6 @@ class ChessDaskCluster:
         game_futures = self.client.map(ChessDaskCluster.analyse_game_in_worker, batch)
         for game_future in as_completed(game_futures):
             game_data = game_future.result()
-            handler(game_data)
\ No newline at end of file
+            handler(game_data)
+
+    
\ No newline at end of file
